package ezc.model;

import java.util.Date;
import java.util.GregorianCalendar;

public class Filtro
{
	private TipoAnnuncio tipo;
	private TipologiaImmobile tipologia;
	private String citta;
	private String zona;
	private int maxRichiesta;
	private boolean ascensore;
	private boolean postoAuto;
	private int periodo;
	
	public Filtro(TipoAnnuncio tipo, TipologiaImmobile tipologia, String citta, String zona, int maxRichiesta, boolean ascensore, boolean postoAuto, int periodo)
	{
		if (tipo == null)
			throw new IllegalArgumentException("tipo");
		
		this.tipo = tipo;
		this.tipologia = tipologia;
		this.citta = citta;
		this.zona = zona;
		this.maxRichiesta = maxRichiesta;
		this.ascensore = ascensore;
		this.postoAuto = postoAuto;
		this.periodo = periodo;
	}
	
	public boolean filtra(Annuncio annuncio)
	{
		return annuncio.getTipo() == tipo &&
			(tipologia == null || annuncio.getTipologia() == tipologia) &&
			(citta == null || citta.isEmpty() || annuncio.getCitta().equalsIgnoreCase(citta)) &&
			(zona == null || zona.isEmpty() || annuncio.getZona().equalsIgnoreCase(zona)) &&
			(maxRichiesta < 0 || annuncio.getRichiesta() <= maxRichiesta) &&
			(!ascensore || annuncio.hasAscensore()) &&
			(!postoAuto || annuncio.hasPostoAuto()) &&
			(periodo < 0 || CheckPeriodo(annuncio.getPubblicazione()));
	}
	
	private boolean CheckPeriodo(Date pubblicazione)
	{
		GregorianCalendar cal = new GregorianCalendar();
		cal.set(GregorianCalendar.HOUR_OF_DAY, 0);
		cal.set(GregorianCalendar.MINUTE, 0);
		cal.set(GregorianCalendar.SECOND, 0);
		cal.set(GregorianCalendar.MILLISECOND, 0);
		cal.add(GregorianCalendar.DAY_OF_YEAR, -periodo);
		return cal.getTime().compareTo(pubblicazione) <= 0;
	}

//	public TipoAnnuncio getTipo()
//	{
//		return tipo;
//	}
//
//	public TipologiaImmobile getTipologia()
//	{
//		return tipologia;
//	}
//
//	public String getCitta()
//	{
//		return citta;
//	}
//
//	public String getZona()
//	{
//		return zona;
//	}
//
//	public int getMaxRichiesta()
//	{
//		return maxRichiesta;
//	}
//
//	public boolean hasAscensore()
//	{
//		return ascensore;
//	}
//
//	public boolean hasPostoAuto()
//	{
//		return postoAuto;
//	}
//
//	public int getPeriodo()
//	{
//		return periodo;
//	}
}
