package ezc.persistence;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.Reader;
import java.text.DateFormat;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Locale;
import java.util.StringTokenizer;

import ezc.model.Annuncio;
import ezc.model.TipologiaImmobile;

public class MyAnnunciReader implements AnnunciReader
{
	private DateFormat dateFormat;
	
	public MyAnnunciReader()
	{
		dateFormat = DateFormat.getDateInstance(DateFormat.SHORT, Locale.ITALY);
	}

	@Override
	public Collection<Annuncio> read(Reader reader) throws IOException, AnnunciFormatException
	{
		BufferedReader bufferedReader = new BufferedReader(reader);
		ArrayList<Annuncio> result = new ArrayList<Annuncio>();
		
		String line;
		while ((line = bufferedReader.readLine()) != null)
		{
			if (!line.trim().isEmpty())
			{
				result.add(readAnnuncio(line));
			}
		}
		
		return result;
	}

	private Annuncio readAnnuncio(String line) throws AnnunciFormatException
	{
		StringTokenizer st = new StringTokenizer(line, ":");
		
		try
		{
			Date data = dateFormat.parse(st.nextToken().trim());
			String codice = st.nextToken().trim();
			TipologiaImmobile tipologia = decodeTipologia(st.nextToken().trim());
			int mq = Integer.parseInt(st.nextToken().trim());
			String descrizione = st.nextToken().trim();
			String zona = st.nextToken().trim();
			String citta = st.nextToken().trim();
			int richiesta = Integer.parseInt(st.nextToken().trim());
			boolean ascensore = false;
			boolean postoAuto = false;
			
			while (st.hasMoreTokens())
			{
				String token = st.nextToken().trim();
				if (token.equalsIgnoreCase("ASC"))
				{
					ascensore = true;
				}
				else if (token.equalsIgnoreCase("PA"))
				{
					postoAuto = true;
				}
				else
				{
					throw new IndexOutOfBoundsException("Valori ammessi 'ASC', 'PA'");
				}
			}
			
			return new Annuncio(codice, tipologia, mq, descrizione, citta, zona, richiesta, ascensore, postoAuto, data);
		}
		catch (Exception e)
		{
			throw new AnnunciFormatException(e);
		}
	}

	private TipologiaImmobile decodeTipologia(String token)
	{
		if (token.equalsIgnoreCase("monolocale"))
		{
			return TipologiaImmobile.MONOLOCALE;
		}
		else if (token.equalsIgnoreCase("bilocale"))
		{
			return TipologiaImmobile.BILOCALE;
		}
		else if (token.equalsIgnoreCase("trilocale"))
		{
			return TipologiaImmobile.TRILOCALE;
		}
		else if (token.equalsIgnoreCase("quadrilocale"))
		{
			return TipologiaImmobile.QUADRILOCALE;
		}
		else if (token.equalsIgnoreCase("villetta"))
		{
			return TipologiaImmobile.VILLETTA;
		}
		else if (token.equalsIgnoreCase("villa"))
		{
			return TipologiaImmobile.VILLA;
		}
		throw new IndexOutOfBoundsException();
	}

}
